@echo off
setlocal enableextensions enabledelayedexpansion

@rem ==================================================================
@rem Header 
@rem
@rem Licensed Materials - Property of IBM Corp.
@rem (C) Copyright IBM Corp. 2004
@rem
@rem All Rights Reserved
@rem US Government Users Restricted Rights - Use, duplication or
@rem disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

    @set SCRIPT_VER=01.05
    @set SCRIPT_DATE=03/20/2006
    @set SCRIPT_SCCS=

@rem ==================================================================
@rem History
@rem
@rem DATE        Ver    Auth         Abstract
@rem ----------  -----  -----------  ----------------------------------
@rem 11/15/2004  00.01  brookh       initial design 
@rem 11/18/2004  01.00  brookh       add "-v" option
@rem 11/26/2004  01.01  brookh       Check server status before stop/start
@rem 11/26/2004  01.02  brookh       .pid file is not reliable immediately after 
@rem                                 start/stop, so only check before first start
@rem 12/08/2004  01.03  brookh       Invalid switch - "/stop," 
@rem                                 (missing "@rem" in 2nd line of prev. comment)
@rem 03/12/2006  01.04  mmarkand     add parsing routine for command line arguments
@rem 03/20/2006  01.05  mmarkand     added option -u to only un-deploy an application

@rem ==================================================================
@rem 
@rem
@rem   Usage: deploy_IDSWebApp.bat [-v] [-h] [-w IDSWebApp.war file] 
@rem				     [-a Application Name] [-u] [-n]
@rem
@rem  Deploys IDSWebApp.war to WAS, retaining the configuration settings 
@rem  of the currently deployed IDSWebApp, if any.
@rem
@rem
@rem  NOTE:  When deploying the application on WebSphere Application Server v6.0,
@rem         deploy_IDSWebApp.sh must be copied to WAS_HOME/bin.
@rem
@rem
@rem
@rem  {-h 	Display Usage. }
@rem
@rem  {-v 	Display the version and date strings for the deploy_IDSWebApp
@rem    	script and the application war file. }
@rem
@rem  {-w 	The fully qualified path of the IDSWebApp.war file to deploy. }
@rem
@rem  {-a 	Application Name. Defaults to IDSWebApp.war if not specified. }
@rem
@rem  {-u 	Uninstall a previously existing application.
@rem       	-a option should be used to specify the application to uninstall
@rem       	If not specified default application IDSWebApp.war would be
@rem            un-deployed. }
@rem
@rem  {-n       (Windows only)
@rem            "no prompt" suppresses the "Press any key to continue . . ."
@rem             prompt at end of script. This is on by default so that users
@rem             running the script from Windows Explorer ("Open", "Run",
@rem             Dbl-click, or drag-n-drop) can review the status messages 
@rem             before the console window is closed.} 
@rem
@rem
@rem  =================================================================

goto :MAIN

@rem ==================================================================
@rem Clear ERRORLEVEL so || and && operators work correctly...
:ClearErrorLevel
    ( dir %COMPSPEC% 2>&1 ) >NUL
goto :EOF

@rem ==================================================================
@rem Print localized "File not found" error and set ERRORLEVEL
:AssertFileExists
    if not exist %1 (
        echo %1
        dir %1 >NUL
    ) else call :ClearErrorLevel
goto :EOF

@rem ==================================================================
@rem Find last '\' in %1 and return S_PATH'\'S_FILE
:Split_Path
    
    set S_PATH=
    set S_FILE=%1
    
    :Split_Path_LOOP
    for /F "usebackq tokens=1* delims=\" %%a in ('!S_FILE!') do (
        if "%%b"=="" (
            set S_FILE=%%a
        ) else (
            set S_FILE=%%b
            if "!S_PATH!"=="" (
                set S_PATH=%%a
            ) else (
                set S_PATH=!S_PATH!\%%a
            )
            goto :Split_Path_LOOP
        )
    )
    
    @rem echo :Split_Path !S_PATH! !S_FILE!
    
goto :EOF


@rem ==================================================================
@rem Echo cmd and then call it
:EchoCmd
    echo.
    echo %*
    call %*
goto :EOF

@rem ==================================================================
@rem Delete %WAS_HOME%\temp\IDSWebApp.tmp directory 
:DeleteTempDirectory
    if exist "!WAS_TEMP!" rmdir /s /q "!WAS_TEMP!" || goto :EOF
    call :ClearErrorLevel
goto :EOF

@rem ==================================================================
@rem Create empty %WAS_HOME%\temp\IDSWebApp.tmp directory w/ dummy file
:CreateTempDirectory
    call :DeleteTempDirectory || goto :EOF
    mkdir "!WAS_TEMP!" || goto :EOF
    call :ClearErrorLevel
goto :EOF

@rem ==================================================================
@rem Parse command line for optional "-n" and IDSWebApp.war file parameters
:ParseCmdLine

    @rem Must clear all the local variables before reading in cmd line options args
    set OPTION_N=
    set OPTION_V=
    set IDSWebApp=
    set WASHOMEPath=
    set BOBCAT_SERV=FALSE
    set UNINSTALL_ONLY=FALSE

    set UNINSTALL_TEMP=!WAS_HOME!\temp\uninstall_IDSWebApp.tmp"

    @rem Auto-detect if we're running from a CMD shell or a GUI
    @rem so we know whether to pause before exiting.
    if exist %CMDCMDLINE% (
        set OPTION_N=TRUE
    ) else (
        set OPTION_N=FALSE
    )

    set setupCmdLine.bat=%~dp0setupCmdLine.bat
    set OPTION_V=FALSE

    @rem any param != "-n" or "-v" is asumed to be the IDSWebApp.war file...
    :ParseCmdLine_NEXT
    	shift
        if "%~0"=="" (
            call :ClearErrorLevel
            goto :EOF
        ) else if "%~0"=="-n" (
            set OPTION_N=TRUE
        ) else if "%~0"=="-v" (
            set OPTION_V=TRUE
        ) else if "%~0%"=="-w" (
            set IDSWebApp=%~f1%
            shift
	) else if "%~0%"=="-a" (
	    set IDSWebApp_Name=%~1
	    set APP_ROOT=!WAS_HOME!\installedApps\DefaultNode\!IDSWebApp_Name!.ear\IDSWebApp.war
	    shift
	) else if "%~0%"=="-u" (
	    set UNINSTALL_ONLY=TRUE
	) else if "%~0%"=="-r" (
	   set PROFILE_NAME=%~1
	   shift
	) else if "%~0%"=="-?" (
	    set OPTION_H=TRUE
	    goto :END
        ) else (
	    set OPTION_H=TRUE
            call :ClearErrorLevel
        )
    goto :ParseCmdLine_NEXT
    @rem end loop :ParseCmdLine_NEXT

goto :EOF

@rem ==================================================================
@rem 
:Backup_File_Uninstall
    
     call :Split_Path %1
     set SRC_FILE=!APP_ROOT!\%1
     set DST_PATH=!UNINSTALL_TEMP!\!S_PATH!
     if exist "!SRC_FILE!" (
	  call :EchoCmd mkdir "!DST_PATH!" || goto :EOF
	  call :EchoCmd copy "!SRC_FILE!" "!DST_PATH!" || goto :EOF
      ) else call :ClearErrorLevel

goto :EOF

@rem ==================================================================
@rem 
:Uninstall_DeleteTempDirectory
     if exist "!UNINSTALL_TEMP!" rmdir /s /q "!UNINSTALL_TEMP!" || goto :EOF
     call :ClearErrorLevel

goto :EOF

@rem ==================================================================
@rem 
:Uninstall_Backup_IDSWebApp_Configuration

    for %%f in (%CONFIG_FILES%) do (
        call :Backup_File_Uninstall %%f || goto :EOF
    )

goto :EOF


@rem ==================================================================
@rem 
:Uninstall_CreateTempDirectory
    call :Uninstall_DeleteTempDirectory || goto :EOF
    mkdir "!UNINSTALL_TEMP!" || goto :EOF
    call :ClearErrorLevel

goto :EOF

@rem ==================================================================
@rem 
:InitGlobalVariables

    set WAS_SERVER=server1
    set WAS_TEMP=!WAS_HOME!\temp\deploy_IDSWebApp.tmp
    set IDSWebAppInfo.xml=WEB-INF\classes\IDSConfig\IDSWebAppInfo\IDSWebAppInfo.xml
    set APP_ROOT=!WAS_HOME!\installedApps\!WAS_NODE!\IDSWebApp.war.ear\IDSWebApp.war
    set CONFIG_FILES=WEB-INF\classes\security\console_passwd WEB-INF\classes\IDSConfig\IDSServersConfig\IDSServersInfo.xml WEB-INF\classes\IDSConfig\IDSAppReg\IDSAppReg.xml WEB-INF\classes\IDSConfig\IDSSessionConfig\IDSSessionMgmt.xml

    @rem if IDSWebApp not passed on cmd line, default to %WAS_HOME%\installableApps
    if "!IDSWebApp!"=="" (
        set IDSWebApp=!WAS_HOME!\installableApps\IDSWebApp.war
    )

    if "!IDSWebApp_Name!"=="" (
            set IDSWebApp_Name=IDSWebApp.war
    )

    set APP_ROOT=!WAS_HOME!\installedApps\!WAS_NODE!\!IDSWebApp_Name!.ear\IDSWebApp.war

goto :EOF

@rem ==================================================================
@rem 
:PrintUsage

 set OPTION_H=TRUE
 echo.
 echo  Usage: deploy_IDSWebApp.bat [-v] [-h] [-w IDSWebApp.war file] 
 echo				     [-a Application Name [-u]] 
 echo.
 echo  Deploys IDSWebApp.war to WAS, retaining the configuration settings 
 echo  of the currently deployed IDSWebApp, if any.
 echo.
 echo.
 echo  NOTE:  When deploying the application on WebSphere Application Server v6.0,
 echo    	deploy_IDSWebApp.bat must be copied to WAS_HOME/bin.
 echo.
 echo.
 echo  {-h 	Display Usage. }
 echo.
 echo  {-v 	Display the version and date strings for the deploy_IDSWebApp
 echo    	script and the application war file. }
 echo.
 echo  {-w 	The fully qualified path of the IDSWebApp.war file to deploy. }
 echo.
 echo  {-a 	Application Name. Defaults to IDSWebApp.war if not specified. }
 echo.
 echo  {-u 	Uninstall a previously existing application.
 echo       	-a option should be used to specify the application to uninstall
 echo       	If not specified default application IDSWebApp.war would be
 echo           un-deployed. }
 echo.


 goto :END

@rem ==================================================================
@rem Copy %1 from APP_ROOT to WAS_TEMP
:Backup_File

    call :Split_Path %1
    set SRC_FILE=!APP_ROOT!\%1
    set DST_PATH=!WAS_TEMP!\!S_PATH!
    if exist "!SRC_FILE!" (
        call :EchoCmd mkdir "!DST_PATH!" || goto :EOF
        call :EchoCmd copy "!SRC_FILE!" "!DST_PATH!" || goto :EOF
    ) else call :ClearErrorLevel

goto :EOF

@rem ==================================================================
@rem Copy %1 from APP_ROOT to WAS_TEMP
:RestoreFile

    set SRC_FILE=!WAS_TEMP!\%1
    set DST_FILE=!APP_ROOT!\%1
    if exist "!SRC_FILE!" (
        call :EchoCmd copy /y "!SRC_FILE!" "!DST_FILE!" || goto :EOF
    ) else call :ClearErrorLevel

goto :EOF

@rem ==================================================================
@rem If IDSWebApp.war is deployed to WAS_NODE of WAS_HOME,
@rem then copy CONFIG_FILES from APP_ROOT to WAS_TEMP
:Backup_IDSWebApp_Configuration

    for %%f in (%CONFIG_FILES%) do (
        call :Backup_File %%f || goto :EOF
    )

goto :EOF

@rem ==================================================================
@rem Restore CONFIG_FILES (if any) from WAS_TEMP to APP_ROOT
:Restore_IDSWebApp_Configuration

    for %%f in (%CONFIG_FILES%) do (
        call :RestoreFile %%f || goto :EOF
    )

goto :EOF

@rem ==================================================================
@rem if WAS is not running, start it
:Start_WAS
    call :EchoCmd "!WAS_HOME!\bin\startServer.bat" !WAS_SERVER!
goto :EOF

@rem ==================================================================
@rem if WAS is running, stop it
:Stop_WAS
    call :EchoCmd "!WAS_HOME!\bin\stopServer.bat" !WAS_SERVER!
goto :EOF

@rem ==================================================================
:Restart_WAS
    call :Stop_WAS
    call :Start_WAS
goto :EOF

@rem ==================================================================
@rem Un-deploy existing IDSWebApp.war (if found)...
@rem TODO - Change the IDSWebApp.war to appname variable

:Uninstall_IDSWebApp

    if exist "!APP_ROOT!\WEB-INF\classes\security\console_passwd" (
        call :EchoCmd "!WAS_HOME!\bin\wsadmin.bat" -c "$AdminApp uninstall !IDSWebApp_Name!"
    ) else call :ClearErrorLevel

goto :EOF

@rem ==================================================================
@rem Deploy existing IDSWebApp.war ...
@rem TODO - Change the IDSWebApp.war to appname variable

:Install_IDSWebApp

    call :EchoCmd "!WAS_HOME!\bin\wsadmin.bat" -conntype NONE -c "$AdminApp install {!IDSWebApp!} {-configroot \"!CONFIG_ROOT!\" -node !WAS_NODE! -usedefaultbindings -nodeployejb -appname !IDSWebApp_Name! -contextroot \"IDSWebApp\"}"

goto :EOF

@rem ==================================================================
@rem Lets you uninstall the existing Web Admin application (-u option)
@rem 
:Uninstall_Only
     echo.
     echo You Have chosen to UNDEPLOY !IDSWebApp_Name! 
     echo.
     echo The Configuration files for the current application would be stored in !WAS_HOME!\temp\uninstall_IDSWebApp.tmp
     echo.
     
     if "!IDSWebApp_Name!"=="" (
     	set IDSWebApp_Name="IDSWebApp.war"
     ) 

     echo An Application name !IDSWebApp_Name! will be un-deployed
     call :Uninstall_CreateTempDirectory
     call :Uninstall_Backup_IDSWebApp_Configuration
          
          if not exist "!WAS_HOME!\logs\!WAS_SERVER!\!WAS_SERVER!.pid" (
  	    	call :Start_WAS || goto :END
	  )
     
     call :Uninstall_IDSWebApp 
     
goto :EOF

@rem ==================================================================
@rem Display app-version and build-date of IDSWebAppInfo.xml file
@rem or localized 'not found' message
:ShowIDSWebAppInfo

    if exist %1 (
        "%WINDIR%\system32\findstr.exe" /L "app-version build-date" %1
    ) else (
        dir %1 >NUL
    )

goto :EOF

@rem ==================================================================
@rem "-v"
:ShowVersionInfo

    @rem Show script version
    echo.
    echo %~f0:
    echo     SCRIPT_VER:  %SCRIPT_VER%
    echo     SCRIPT_DATE: %SCRIPT_DATE%

    @rem Show version of new IDSWebApp
    echo.
    echo !IDSWebApp!:
    if exist "!IDSWebApp!" (
        pushd "!WAS_TEMP!"
        "!JAVA_HOME!\bin\jar.exe" -xf "!IDSWebApp!" !IDSWebAppInfo.xml!
        popd
        if exist "!WAS_TEMP!\!IDSWebAppInfo.xml!" (
            call :ShowIDSWebAppInfo "!WAS_TEMP!\!IDSWebAppInfo.xml!"
        ) else (
            echo     Not a valid IDSWebApp.war file?
        )
    ) else (
        dir "!IDSWebApp!" >NUL
    )

    @rem Show version of installed IDSWebApp
    @rem echo.
    @rem echo !APP_ROOT!:
    @rem call :ShowIDSWebAppInfo "!APP_ROOT!\!IDSWebAppInfo.xml!"

goto :EOF



@rem ==================================================================
:MAIN

    call :ParseCmdLine %*

        if "!OPTION_H!"=="TRUE" (
    	   call :PrintUsage
    	   goto :END
    )

    @rem call %WAS_HOME%\bin\setupCmdLine.bat
        call :AssertFileExists "!setupCmdLine.bat!" || goto :END
        call "!setupCmdLine.bat!" || goto :END

    @rem Initialize global variables...
        call :InitGlobalVariables
    
    @rem we need a tmp directory...
        call :CreateTempDirectory || goto :END
        call :AssertFileExists "!WAS_TEMP!" || goto :END
        
    @rem if "-v"...
        if "!OPTION_V!"=="TRUE" (
            call :ShowVersionInfo
            goto :SUCCESS
        )

    @rem check if we just want to uninstall the existing application
    @rem "-u"...
        if !UNINSTALL_ONLY!==TRUE (
	call :Uninstall_Only
	goto :END
    )
        
    @rem if we're actually going to install the new .war, it must exist
        call :AssertFileExists "!IDSWebApp!" || goto :END

    @rem Backup existing configuration (if found)...
        call :Backup_IDSWebApp_Configuration || goto :END

    @rem WAS must be running...
        if not exist "!WAS_HOME!\logs\!WAS_SERVER!\!WAS_SERVER!.pid" (
            call :Start_WAS || goto :END
        )
        call :ClearErrorLevel
    
    @rem Un-deploy existing IDSWebApp.war (if found)...
        call :Uninstall_IDSWebApp || goto :END

    @rem Deploy new IDSWebApp.war ...
        call :Install_IDSWebApp || goto :END
        
    @rem Restore previous configuration (if any)...
        call :Restore_IDSWebApp_Configuration
        
    @rem Restart WAS
        call :Restart_WAS

:SUCCESS
    call :DeleteTempDirectory
    echo.
    echo "!APP_ROOT!"
    call :ShowIDSWebAppInfo "!APP_ROOT!\!IDSWebAppInfo.xml!"
    
goto :END

@rem ==================================================================
:END
if not "!OPTION_N!"=="TRUE" pause
endlocal
